@@ -20,27 +20,59 @@
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="63"/>
-        <source>File</source>
+        <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="71"/>
-        <source>Help</source>
+        <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="81"/>
-        <source>Load...</source>
+        <location filename="../src/mainwindow.ui" line="84"/>
+        <source>&amp;Open…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="86"/>
-        <source>Exit</source>
+        <location filename="../src/mainwindow.ui" line="87"/>
+        <source>Open a XRechnung file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="91"/>
-        <source>About XRView...</source>
+        <location filename="../src/mainwindow.ui" line="90"/>
+        <source>Ctrl+O</source>
+        <comment>File open</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="98"/>
+        <source>&amp;Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="101"/>
+        <source>Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="104"/>
+        <source>Exit the program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="107"/>
+        <source>Ctrl+Q</source>
+        <comment>Exit the program</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="115"/>
+        <source>About XRView</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.ui" line="112"/>
+        <source>&amp;About XRView…</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -112,12 +144,12 @@ Should they be downloaded from Github?</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/main.cpp" line="44"/>
+        <location filename="../src/main.cpp" line="71"/>
         <source>xrechnung</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="44"/>
+        <location filename="../src/main.cpp" line="71"/>
         <source>List of xrechnung</source>
         <translation type="unfinished"></translation>
     </message>
